@@ -13,12 +13,12 @@ if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
   fi
 fi
 
-( cd usr/doc/OpenJDK11-11.0.28 ; rm -rf legal )
-( cd usr/doc/OpenJDK11-11.0.28 ; ln -sf ../../lib64/OpenJDK11-11.0.28/legal legal )
-( cd usr/doc/OpenJDK11-11.0.28 ; rm -rf release )
-( cd usr/doc/OpenJDK11-11.0.28 ; ln -sf ../../lib64/OpenJDK11-11.0.28/release release )
-( cd usr/lib64 ; rm -rf OpenJDK11-11.0.28 )
-( cd usr/lib64 ; ln -sf java OpenJDK11-11.0.28 )
+( cd usr/doc/OpenJDK17-17.0.16 ; rm -rf legal )
+( cd usr/doc/OpenJDK17-17.0.16 ; ln -sf ../../lib64/OpenJDK17-17.0.16/legal legal )
+( cd usr/doc/OpenJDK17-17.0.16 ; rm -rf release )
+( cd usr/doc/OpenJDK17-17.0.16 ; ln -sf ../../lib64/OpenJDK17-17.0.16/release release )
+( cd usr/lib64 ; rm -rf OpenJDK17-17.0.16 )
+( cd usr/lib64 ; ln -sf java OpenJDK17-17.0.16 )
 ( cd usr/lib64/java/legal/java.compiler ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/java.compiler ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/java.compiler ; rm -rf ASSEMBLY_EXCEPTION )
@@ -151,12 +151,6 @@ fi
 ( cd usr/lib64/java/legal/jdk.accessibility ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
 ( cd usr/lib64/java/legal/jdk.accessibility ; rm -rf LICENSE )
 ( cd usr/lib64/java/legal/jdk.accessibility ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.aot ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.aot ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.aot ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.aot ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.aot ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.aot ; ln -sf ../java.base/LICENSE LICENSE )
 ( cd usr/lib64/java/legal/jdk.attach ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.attach ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.attach ; rm -rf ASSEMBLY_EXCEPTION )
@@ -211,6 +205,18 @@ fi
 ( cd usr/lib64/java/legal/jdk.httpserver ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
 ( cd usr/lib64/java/legal/jdk.httpserver ; rm -rf LICENSE )
 ( cd usr/lib64/java/legal/jdk.httpserver ; ln -sf ../java.base/LICENSE LICENSE )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf LICENSE )
+( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/LICENSE LICENSE )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf LICENSE )
+( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/LICENSE LICENSE )
 ( cd usr/lib64/java/legal/jdk.internal.ed ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.internal.ed ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.internal.ed ; rm -rf ASSEMBLY_EXCEPTION )
@@ -307,6 +313,12 @@ fi
 ( cd usr/lib64/java/legal/jdk.jlink ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
 ( cd usr/lib64/java/legal/jdk.jlink ; rm -rf LICENSE )
 ( cd usr/lib64/java/legal/jdk.jlink ; ln -sf ../java.base/LICENSE LICENSE )
+( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf LICENSE )
+( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/LICENSE LICENSE )
 ( cd usr/lib64/java/legal/jdk.jshell ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.jshell ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.jshell ; rm -rf ASSEMBLY_EXCEPTION )
@@ -357,12 +369,6 @@ fi
 ( cd usr/lib64/java/legal/jdk.naming.dns ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
 ( cd usr/lib64/java/legal/jdk.naming.dns ; rm -rf LICENSE )
 ( cd usr/lib64/java/legal/jdk.naming.dns ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.naming.ldap ; ln -sf ../java.base/LICENSE LICENSE )
 ( cd usr/lib64/java/legal/jdk.naming.rmi ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.naming.rmi ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.naming.rmi ; rm -rf ASSEMBLY_EXCEPTION )
@@ -375,30 +381,18 @@ fi
 ( cd usr/lib64/java/legal/jdk.net ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
 ( cd usr/lib64/java/legal/jdk.net ; rm -rf LICENSE )
 ( cd usr/lib64/java/legal/jdk.net ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.pack ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.pack ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.pack ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.pack ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.pack ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.pack ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.rmic ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.rmic ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.rmic ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.rmic ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.rmic ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.rmic ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn.shell ; ln -sf ../java.base/LICENSE LICENSE )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; rm -rf ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; rm -rf ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; rm -rf LICENSE )
-( cd usr/lib64/java/legal/jdk.scripting.nashorn ; ln -sf ../java.base/LICENSE LICENSE )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf LICENSE )
+( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/LICENSE LICENSE )
+( cd usr/lib64/java/legal/jdk.random ; rm -rf ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
+( cd usr/lib64/java/legal/jdk.random ; rm -rf ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
+( cd usr/lib64/java/legal/jdk.random ; rm -rf LICENSE )
+( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/LICENSE LICENSE )
 ( cd usr/lib64/java/legal/jdk.sctp ; rm -rf ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.sctp ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
 ( cd usr/lib64/java/legal/jdk.sctp ; rm -rf ASSEMBLY_EXCEPTION )
